import 'package:flutter/material.dart';
import 'package:phone_form_field/l10n/generated/phone_field_localization.dart';
import 'package:phone_form_field/src/models/country.dart';

typedef TranslateCountryFn = String? Function(BuildContext ctx);

class CountryTranslator {
  static final Map<String, TranslateCountryFn> _countryNames = {
    'AD': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ad_,
    'AE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ae_,
    'AF': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.af_,
    'AG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ag_,
    'AI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ai_,
    'AL': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.al_,
    'AM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.am_,
    'AN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.an_,
    'AO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ao_,
    'AQ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.aq_,
    'AR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ar_,
    'AS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.as_,
    'AT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.at_,
    'AU': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.au_,
    'AW': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.aw_,
    'AX': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ax_,
    'AZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.az_,
    'BA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ba_,
    'BB': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bb_,
    'BD': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bd_,
    'BE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.be_,
    'BF': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bf_,
    'BG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bg_,
    'BH': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bh_,
    'BI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bi_,
    'BJ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bj_,
    'BL': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bl_,
    'BM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bm_,
    'BN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bn_,
    'BO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bo_,
    'BR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.br_,
    'BS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bs_,
    'BT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bt_,
    'BW': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bw_,
    'BY': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.by_,
    'BZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.bz_,
    'CA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ca_,
    'CC': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cc_,
    'CD': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cd_,
    'CF': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cf_,
    'CG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cg_,
    'CH': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ch_,
    'CI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ci_,
    'CK': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ck_,
    'CL': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cl_,
    'CM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cm_,
    'CN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cn_,
    'CO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.co_,
    'CR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cr_,
    'CU': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cu_,
    'CV': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cv_,
    'CX': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cx_,
    'CY': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cy_,
    'CZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.cz_,
    'DE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.de_,
    'DJ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.dj_,
    'DK': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.dk_,
    'DM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.dm_,
    'DO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.do_,
    'DZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.dz_,
    'EC': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ec_,
    'EE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ee_,
    'EG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.eg_,
    'ER': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.er_,
    'ES': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.es_,
    'ET': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.et_,
    'FI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.fi_,
    'FJ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.fj_,
    'FK': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.fk_,
    'FM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.fm_,
    'FO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.fo_,
    'FR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.fr_,
    'GA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ga_,
    'GB': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gb_,
    'GD': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gd_,
    'GE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ge_,
    'GF': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gf_,
    'GG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gg_,
    'GH': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gh_,
    'GI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gi_,
    'GL': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gl_,
    'GM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gm_,
    'GN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gn_,
    'GP': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gp_,
    'GQ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gq_,
    'GR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gr_,
    'GS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gs_,
    'GT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gt_,
    'GU': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gu_,
    'GW': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gw_,
    'GY': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.gy_,
    'HK': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.hk_,
    'HN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.hn_,
    'HR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.hr_,
    'HT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ht_,
    'HU': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.hu_,
    'ID': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.id_,
    'IE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ie_,
    'IL': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.il_,
    'IM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.im_,
    'IN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.in_,
    'IO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.io_,
    'IQ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.iq_,
    'IR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ir_,
    'IS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.is_,
    'IT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.it_,
    'JE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.je_,
    'JM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.jm_,
    'JO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.jo_,
    'JP': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.jp_,
    'KE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ke_,
    'KG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.kg_,
    'KH': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.kh_,
    'KI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ki_,
    'KM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.km_,
    'KN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.kn_,
    'KP': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.kp_,
    'KR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.kr_,
    'KW': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.kw_,
    'KY': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ky_,
    'KZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.kz_,
    'LA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.la_,
    'LB': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.lb_,
    'LC': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.lc_,
    'LI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.li_,
    'LK': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.lk_,
    'LR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.lr_,
    'LS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ls_,
    'LT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.lt_,
    'LU': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.lu_,
    'LV': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.lv_,
    'LY': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ly_,
    'MA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ma_,
    'MC': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mc_,
    'MD': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.md_,
    'ME': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.me_,
    'MF': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mf_,
    'MG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mg_,
    'MH': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mh_,
    'MK': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mk_,
    'ML': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ml_,
    'MM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mm_,
    'MN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mn_,
    'MO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mo_,
    'MP': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mp_,
    'MQ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mq_,
    'MR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mr_,
    'MS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ms_,
    'MT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mt_,
    'MU': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mu_,
    'MV': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mv_,
    'MW': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mw_,
    'MX': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mx_,
    'MY': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.my_,
    'MZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.mz_,
    'NA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.na_,
    'NC': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.nc_,
    'NE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ne_,
    'NF': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.nf_,
    'NG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ng_,
    'NI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ni_,
    'NL': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.nl_,
    'NO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.no_,
    'NP': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.np_,
    'NR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.nr_,
    'NU': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.nu_,
    'NZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.nz_,
    'OM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.om_,
    'PA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pa_,
    'PE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pe_,
    'PF': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pf_,
    'PG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pg_,
    'PH': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ph_,
    'PK': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pk_,
    'PL': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pl_,
    'PM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pm_,
    'PN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pn_,
    'PR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pr_,
    'PS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ps_,
    'PT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pt_,
    'PW': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.pw_,
    'PY': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.py_,
    'QA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.qa_,
    'RE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.re_,
    'RO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ro_,
    'RS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.rs_,
    'RU': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ru_,
    'RW': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.rw_,
    'SA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sa_,
    'SB': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sb_,
    'SC': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sc_,
    'SD': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sd_,
    'SE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.se_,
    'SG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sg_,
    'SH': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sh_,
    'SI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.si_,
    'SJ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sj_,
    'SK': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sk_,
    'SL': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sl_,
    'SM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sm_,
    'SN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sn_,
    'SO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.so_,
    'SR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sr_,
    'SS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ss_,
    'ST': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.st_,
    'SV': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sv_,
    'SY': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sy_,
    'SZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.sz_,
    'TC': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tc_,
    'TD': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.td_,
    'TG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tg_,
    'TH': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.th_,
    'TJ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tj_,
    'TK': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tk_,
    'TL': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tl_,
    'TM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tm_,
    'TN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tn_,
    'TO': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.to_,
    'TR': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tr_,
    'TT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tt_,
    'TV': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tv_,
    'TW': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tw_,
    'TZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.tz_,
    'UA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ua_,
    'UG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ug_,
    'US': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.us_,
    'UY': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.uy_,
    'UZ': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.uz_,
    'VA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.va_,
    'VC': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.vc_,
    'VE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ve_,
    'VG': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.vg_,
    'VI': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.vi_,
    'VN': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.vn_,
    'VU': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.vu_,
    'WF': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.wf_,
    'WS': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ws_,
    'YE': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.ye_,
    'YT': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.yt_,
    'ZA': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.za_,
    'ZM': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.zm_,
    'ZW': (BuildContext ctx) => PhoneFieldLocalization.of(ctx)?.zw_
  };

  /// Localised name depending on the current application locale
  /// If you have many LocalisedName to handle in a same context, consider
  /// supplying the second optional PhoneFieldLocalization to avoid
  /// walking up the widget to get [PhoneFieldLocalization] instance
  /// for each call.
  static String localisedName(
    BuildContext context,
    Country country,
  ) {
    String? name = getCountryNameForIsoCode(context, country.isoCode);
    return name ?? country.name;
  }

  static String? getCountryNameForIsoCode(BuildContext ctx, String isoCode) {
    final TranslateCountryFn? translateFn =
        _countryNames[isoCode.toUpperCase()];
    return translateFn?.call(ctx);
  }
}
